==> rebot-0.9.tar.gz: rebot-0.9/irc_lang_es.pm <==
package irc_lang_es;

#   Rebot 0.9 (beta): Bot para aventuras de texto por red
#   http://aventuras.presi.org/rebot
#   (C) 2005 Enrique D. Bosch 'presi'
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
#   http://www.gnu.org/licenses/gpl.html

# Cadenas en espaol del mdulo de irc de rebot (irc.pm)
# Mensajes

$ini         = 'Mdulo de protocolo IRC versin 0.9 (beta) para rebot';
$connected   = 'irc: Conectado';
$mod         = 'irc: Estableciendo modo de usuario';
$priv        = 'irc: Mensaje privado de';
$no_com      = 'Comando no reconocido';
$no_com_aut  = 'irc: Comando no autorizado de';
$nick        = 'irc: Nick';
$uso         = 'en uso o registrado, cambiado a';
$ping        = 'irc: CTCP Ping solicitado por';
$version     = 'irc: CTCP Version solicitado por';
$join        = 'irc: Entrando al canal';
$part        = 'irc: Saliendo del canal';
$aut         = 'autentificado por password';
$come        = "Los comentarios en el canal ahora deben empezar por . , ', # o !";
$coma        = "Los comandos en el canal ahora deben empezar por . , ' , # o !";
$com         = "irc: Cambiados comentarios a . ' # !";
$com_no      = "irc: Cambiados comentarios a NO . ' # !";
$aut_master  = 'irc: Autenticado el usuario maestro';
$aut         = 'Autenticado';
$user        = 'irc: Usuario';
$no_master   = 'no est autorizado para autenticarse como maestro';
$op_master   = 'irc: Dando op al usuario maestro';
$no_op       = 'no est autorizado para obtener op';
$no_aut      = 'No autorizado';
$no_deaut    = 'no puede deautenticarse';
$deaut       = 'deautenticado';
$deaut_m     = 'Deautenticado';
$help_c      = "Los comandos (tanto del bot como del juego)\nestando en canal pblico deben comenzar por . , # , ' o !";
$help_nc     = "Las lneas que comiencen por . , # , ' o ! son\nignoradas (por ejemplo para poner comentarios)";
$help1       = '  canal <canal>
     Cambia el canal de IRC en el que rebot est.
  master [password]
     Autentifica al usuario maestro mediante password si es
     necesaria.
  op [password]
     Da op si se es el usuario maestro. Se deber especificar
     la password de usuario maestro si es necesaria.
  finalizar
     Finaliza una sesin como maestro.
  salir
     Termina la ejecucin del bot.
';
$help2       = '
esto puede cambiarse con el comando \'cambio\' o \'cambiar\'.
Algunos de estos comandos pueden estar permitidos slo a
usuarios con op o al usuario maestro.';

# Comandos

$canal       = 'canal';
$cambio      = 'cambio';
$cambiar     = 'cambiar';
$master      = 'master';
$op          = 'op';
$salir       = 'salir';
$finalizar   = 'finalizar';

1;

==> rebot-0.9.1.tar.gz: rebot-0.9.1/irc_lang_es.pm <==
package irc_lang_es;

#   Rebot 0.9.1 (beta): Bot para aventuras de texto por red
#   http://aventuras.presi.org/rebot
#   (C) 2005 Enrique D. Bosch 'presi'
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
#   http://www.gnu.org/licenses/gpl.html

# Cadenas en espaol del mdulo de irc de rebot (irc.pm)
# Mensajes

$ini         = 'Mdulo de protocolo IRC versin 0.9.1 (beta) para rebot';
$connected   = 'irc: Conectado';
$mod         = 'irc: Estableciendo modo de usuario';
$priv        = 'irc: Mensaje privado de';
$no_com      = 'Comando no reconocido';
$no_com_aut  = 'irc: Comando no autorizado de';
$nick        = 'irc: Nick';
$uso         = 'en uso o registrado, cambiado a';
$ping        = 'irc: CTCP Ping solicitado por';
$version     = 'irc: CTCP Version solicitado por';
$join        = 'irc: Entrando al canal';
$part        = 'irc: Saliendo del canal';
$aut         = 'autentificado por password';
$come        = "Los comentarios en el canal ahora deben empezar por . , ', # o !";
$coma        = "Los comandos en el canal ahora deben empezar por . , ' , # o !";
$com         = "irc: Cambiados comentarios a . ' # !";
$com_no      = "irc: Cambiados comentarios a NO . ' # !";
$aut_master  = 'irc: Autenticado el usuario maestro';
$aut         = 'Autenticado';
$user        = 'irc: Usuario';
$no_master   = 'no est autorizado para autenticarse como maestro';
$op_master   = 'irc: Dando op al usuario maestro';
$no_op       = 'no est autorizado para obtener op';
$no_aut      = 'No autorizado';
$no_deaut    = 'no puede deautenticarse';
$deaut       = 'deautenticado';
$deaut_m     = 'Deautenticado';
$help_c      = "Los comandos (tanto del bot como del juego)\nestando en canal pblico deben comenzar por . , # , ' o !";
$help_nc     = "Las lneas que comiencen por . , # , ' o ! son\nignoradas (por ejemplo para poner comentarios)";
$help1       = '  canal <canal>
     Cambia el canal de IRC en el que rebot est.
  master [password]
     Autentifica al usuario maestro mediante password si es
     necesaria.
  op [password]
     Da op si se es el usuario maestro. Se deber especificar
     la password de usuario maestro si es necesaria.
  finalizar
     Finaliza una sesin como maestro.
  salir
     Termina la ejecucin del bot.
';
$help2       = '
esto puede cambiarse con el comando \'cambio\' o \'cambiar\'.
Algunos de estos comandos pueden estar permitidos slo a
usuarios con op o al usuario maestro.';

# Comandos

$canal       = 'canal';
$cambio      = 'cambio';
$cambiar     = 'cambiar';
$master      = 'master';
$op          = 'op';
$salir       = 'salir';
$finalizar   = 'finalizar';

1;
